OC.L10N.register(
    "settings",
    {
    "Private" : "Privatus",
    "Local" : "Vietinis",
    "Federated" : "Federacinis",
    "Only synchronize to trusted servers" : "Sinchronizuoti tik į patikimus serverius",
    "Synchronize to trusted servers and the global and public address book" : "Sinchronizuoti į patikimus serverius ir į visuotinę bei viešą adresų knygą",
    "Verify" : "Patikrinti",
    "Verifying …" : "Tikrinama...",
    "Unable to change password" : "Nepavyksta pakeisti slaptažodžio",
    "Very weak password" : "Labai silpnas slaptažodis",
    "Weak password" : "Silpnas slaptažodis",
    "So-so password" : "Neblogas slaptažodis",
    "Good password" : "Geras slaptažodis",
    "Strong password" : "Stiprus slaptažodis",
    "An error occurred while changing your language. Please reload the page and try again." : "Keičiant jūsų kalbą, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Keičiant jūsų lokalę, įvyko klaida. Įkelkite puslapį iš naujo ir bandykite dar kartą.",
    "Week starts on {fdow}" : "Savaitės pradžia yra {fdow}",
    "Groups" : "Grupės",
    "Group list is empty" : "Grupės sąrašas yra tuščias",
    "Unable to retrieve the group list" : "Nepavyko nuskaityti grupių sąrašo",
    "{actor} added you to group {group}" : "{actor} pridėjo jus į grupę {group}",
    "You added {user} to group {group}" : "Jūs pridėjote naudotoją {user} į grupę {group}",
    "{actor} added {user} to group {group}" : "{actor} pridėjo naudotoją {user} į grupę {group}",
    "An administrator added you to group {group}" : "Administratorius pridėjo jus į grupę {group}",
    "An administrator added {user} to group {group}" : "Administratorius pridėjo naudotoją {user} į grupę {group}",
    "{actor} removed you from group {group}" : "{actor} pašalino jus iš grupės {group}",
    "You removed {user} from group {group}" : "Jūs pašalinote naudotoją {user} iš grupės {group}",
    "{actor} removed {user} from group {group}" : "{actor} pašalino naudotoją {user} iš grupės {group}",
    "An administrator removed you from group {group}" : "Administratorius pašalino jus iš grupės {group}",
    "An administrator removed {user} from group {group}" : "Administratorius pašalino naudotoją {user} iš grupės {group}",
    "Your <strong>group memberships</strong> were modified" : "Jūsų <strong>narystės grupėse</strong> buvo modifikuotos",
    "{actor} changed your password" : "{actor} pakeitė jūsų slaptažodį",
    "You changed your password" : "Jūs pakeitėte savo slaptažodį",
    "Your password was reset by an administrator" : "Administratorius atstatė jūsų slaptažodį",
    "Your password was reset" : "Jūsų slaptažodis buvo atstatytas",
    "{actor} changed your email address" : "{actor} pakeitė jūsų el. pašto adresą",
    "You changed your email address" : "Jūs pakeitėte savo el. pašto adresą",
    "Your email address was changed by an administrator" : "Administratorius pakeitė jūsų el. pašto adresą",
    "You created app password \"{token}\"" : "Jūs sukūrėte programėlės slaptažodį \"{token}\"",
    "You deleted app password \"{token}\"" : "Jūs ištrynėte programėlės slaptažodį \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Jūs pervadinote programėlės slaptažodį \"{token}\" į \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Jūs suteikėte failų sistemai prieigą prie programos slaptažodžio  „{token}“.",
    "You revoked filesystem access from app password \"{token}\"" : "Jūs atšaukėte  failų sistemos prieigą prie programos slaptažodžio „{token}“\n \n\n \n \n \n ",
    "Security" : "Saugumas",
    "You successfully logged in using two-factor authentication (%1$s)" : "Jūs sėkmingai prisijungėte, naudodami dviejų faktorių tapatybės nustatymą (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Nepavyko prisijungti, naudojant dviejų faktorių tapatybės nustatymą (%1$s)",
    "Remote wipe was started on %1$s" : "Nuotolinių duomenų ištrynimas buvo pradėtas ties %1$s",
    "Remote wipe has finished on %1$s" : "Nuotolinių duomenų ištrynimas užbaigtas ties %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Jūsų <strong>slaptažodis</strong> ar <strong>el. paštas</strong> buvo pakeisti",
    "Wrong password" : "Neteisingas slaptažodis",
    "Saved" : "Įrašyta",
    "No user supplied" : "Nepateiktas naudotojas",
    "Authentication error" : "Tapatybės nustatymo klaida",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Pateikite administratoriaus atkūrimo slaptažodį; kitu atveju visi naudotojo duomenis bus prarasti.",
    "Wrong admin recovery password. Please check the password and try again." : "Netinkamas administratoriaus atkūrimo slaptažodis. Prašome pasitikrinti ir bandyti vėl.",
    "Federated Cloud Sharing" : "Bendrinimas federacinėje debesijoje",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL naudoja pasenusią %1$s versiją (%2$s). Atnaujinkite savo operacinę sistemą arba tokios ypatybės kaip %3$s neveiks patikimai.",
    "Invalid SMTP password." : "Neteisingas SMTP slaptažodis.",
    "Email setting test" : "El. pašto nustatymo testas",
    "Well done, %s!" : "Gerai padirbėjote, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jeigu gavote šį laišką, tuomet atrodo, jog el. pašto konfigūracija yra teisinga.",
    "Email could not be sent. Check your mail server log" : "El. laiškas nebuvo išsiųstas. Peržiūrėkite savo pašto serverio žurnalą.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Siunčiant el. laišką atsirado problemų. Peržiūrėkite savo nustatymus. (Klaida: %s)",
    "Invalid user" : "Neteisingas naudotojas",
    "Invalid mail address" : "Neteisingas pašto adresas",
    "Settings saved" : "Nustatymai įrašyti",
    "Unable to change full name" : "Nepavyko pakeisti vardo ir pavardės",
    "Unable to change email address" : "Nepavyko pakeisti el. pašto adresą",
    "Some account data was invalid" : "Kai kurie paskyros duomenys buvo neteisingi",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Norėdami patvirtinti savo „Twitter“ paskyrą, paskelbkite šį trumpą įrašą  „Twitter“ programoje (prašome, įsitikinkite kad įrašas neturi jokių jokių eilutės pertraukų):\n  ",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Norėdami patvirtinti savo Saityną, išsaugokite turinį web-root aplanke: „.well-know/CloudIdVerificationCode.txt“ (Prašome įsitikinkite, kad visas tekstas yra vienoje eilutėje):",
    "%1$s changed your password on %2$s." : "%1$s pakeitė jūsų slaptažodį %2$s",
    "Your password on %s was changed." : "Jūsų %s slaptažodis buvo pakeistas. ",
    "Your password on %s was reset by an administrator." : "Administratorius atstatė Jūsų %s slaptažodį.  ",
    "Your password on %s was reset." : "Jūsų %s slaptažodis buvo atstatytas.",
    "Password for %1$s changed on %2$s" : "%1$s slaptažodis, buvo pakeistas ant %2$s",
    "Password changed for %s" : "Pakeistas %s slaptažodis",
    "If you did not request this, please contact an administrator." : "Jeigu nebuvote to užklausę, susisiekite su administratoriumi.",
    "Your email address on %s was changed." : "Buvo pakeistas Jūsų el. pašto adress ant %s.",
    "Your email address on %s was changed by an administrator." : "Administratorius pakeitė Jūsų el. pašto adresą ant %s.",
    "Email address for %1$s changed on %2$s" : "%1$s el. pašto adresas buvo pakeistas ant %2$s. ",
    "Email address changed for %s" : "Pakeistas %s el. pašto adresas. ",
    "The new email address is %s" : "Naujasis el. pašto adresas yra %s",
    "Your %s account was created" : "Jūsų paskyra %s sukurta",
    "Welcome aboard" : "Sveikiname prisijungus",
    "Welcome aboard %s" : "%s, sveikiname prisijungus",
    "Welcome to your %s account, you can add, protect, and share your data." : "Turėdami %s paskyrą duomenis galite pridėti, apsaugoti ir jais pasidalinti.",
    "Your username is: %s" : "Jūsų naudotojo vardas yra: %s",
    "Set your password" : "Nustatykite savo slaptažodį.",
    "Go to %s" : "Pereiti į %s",
    "Install Client" : "Įdiegti kliento programą",
    "Logged in user must be a subadmin" : "Prisijungęs naudotojas privalo būti administratoriaus pavaduotojas",
    "Apps" : "Programėlės",
    "Settings" : "Nustatymai",
    "Personal" : "Asmeniniai",
    "Administration" : "Administravimas",
    "Additional settings" : "Papildomi nustatymai",
    "Groupware" : "Grupinio darbo įranga",
    "Overview" : "Apžvalga",
    "Basic settings" : "Pagrindiniai nustatymai",
    "Sharing" : "Bendrinimas",
    "Personal info" : "Asmeninė informacija",
    "Mobile & desktop" : "Mobilieji ir darbalaukiai",
    "Email server" : "El. pašto serveris",
    "Security & setup warnings" : "Saugumo ir sąrankos įspėjimai",
    "Background jobs" : "Foninės užduotys",
    "Create" : "Sukurti",
    "Change" : "Keisti",
    "Delete" : "Ištrinti",
    "Reshare" : "Pakartotinai bendrinti",
    "Unlimited" : "Neribotai",
    "Verifying" : "Tikrinimas",
    "Nextcloud settings" : "Nextcloud nustatymai",
    "None" : "Nėra",
    "Two-Factor Authentication" : "Dviejų faktorių tapatybės nustatymas",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dviejų faktorių tapatybės nustatymas gali būti priverstinis visiems naudotojams ir tam tikroms grupėms. Jeigu naudotojai ar grupės neturės sukonfigūruoto dviejų faktorių teikėjo, tuomet jie negalės prisijungti prie sistemos.",
    "Enforce two-factor authentication" : "Priversti naudoti dviejų faktorių tapatybės nustatymą",
    "Limit to groups" : "Apriboti iki grupių",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Priverstinis dviejų faktorių tapatybės nustatymas gali būti nustatytas tik tam tikroms grupėms.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dviejų faktorių tapatybės nustatymas yra priverstinis visiems šių grupių nariams.",
    "Enforced groups" : "Priverstines grupės",
    "Two-factor authentication is not enforced for members of the following groups." : "Dviejų faktorių tapatybės nustatymas nėra priverstinis šių grupių nariams.",
    "Excluded groups" : "Pašalintos grupės",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Jei nepasirinkta nė viena grupė, 2FA įjungiama visiems, išskyrus pašalintų grupių narius. Jei pasirenkamos grupės, visiems jų nariams įjungiama 2FA. Jei vartotojas yra ir pasirinktoje, ir pašalintoje grupėje,  2FA yra įjungiamas. ",
    "Save changes" : "Įrašyti pakeitimus",
    "All" : "Viskas",
    "Limit app usage to groups" : "Programos panaudojimas ribojamas grupėms",
    "No results" : "Rezultatų nėra",
    "Update to {version}" : "Atnaujinti į versiją {version}",
    "Remove" : "Šalinti",
    "Disable" : "Išjungti",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos žemiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ši programėlė neturi priskirtos aukščiausios „Nextcloud“ versijos. Ateityje tai bus klaida.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ši programėlė negali būti įdiegta, nes nėra patenkintos žemiau išvardintos priklausomybės:",
    "View in store" : "Rodyti parduotuvėje",
    "Visit website" : "Aplankyti svetainę",
    "Report a bug" : "Pranešti apie klaidą",
    "User documentation" : "Naudotojo dokumentacija",
    "Admin documentation" : "Administratoriaus dokumentacija",
    "Developer documentation" : "Plėtotojo dokumentacija",
    "This app is supported via your current Nextcloud subscription." : "Ši programėlė yra palaikoma per jūsų esamą Nextcloud prenumeratą.",
    "Supported" : "Palaikoma",
    "Update to {update}" : "Atnaujinti į {update}",
    "All apps are up-to-date." : "Visos programėlės yra naujausios laidos.",
    "Results from other categories" : "Rezultatai iš kitų kategorijų",
    "No apps found for your version" : "Jūsų versijai programėlių nėra",
    "Disable all" : "Išjungti visas",
    "Enable all" : "Įjungti visas",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n programėlei yra prieinamas atnaujinimas","%n programėlėms yra prieinamas atnaujinimas","%n programėlių yra prieinamas atnaujinimas","%n programėlei yra prieinamas atnaujinimas"],
    "_Update_::_Update all_" : ["Atnaujinti","Atnaujinti visas","Atnaujinti visas","Atnaujinti visas"],
    "Marked for remote wipe" : "Pažymėtas nuotolinių duomenų ištrynimui",
    "Device settings" : "Įrenginio nustatymai",
    "Allow filesystem access" : "Leisti prieigą prie failų sistemos",
    "Rename" : "Pervadinti",
    "Revoke" : "Panaikinti",
    "Wipe device" : "Ištrinti duomenis įrenginyje",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome, skirta Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Sync client - {os}" : "Sinchronizavimo klientas - {os}",
    "This session" : "Šis seansas",
    "Device" : "Įrenginys",
    "Last activity" : "Paskutinė veikla",
    "Devices & sessions" : "Įrenginiai ir seansai",
    "Web, desktop and mobile clients currently logged in to your account." : "Saityno, darbalaukio ir mobilieji klientai, kurie šiuo metu yra prisijungę prie jūsų paskyros.",
    "Do you really want to wipe your data from this device?" : "Ar tikrai norite ištrinti šiame įrenginyje esančius savo duomenis?",
    "Confirm wipe" : "Patvirtinti duomenų ištrynimą",
    "Error while creating device token" : "Klaida, kuriant įrenginio prieigos raktą",
    "Error while updating device token scope" : "Įvyko klaida atnaujinant įrenginio prieigos rakto taikymą",
    "Error while updating device token name" : "Įvyko klaida atnaujinant įrenginio prieigos rakto pavadinimą",
    "Error while deleting the token" : "Klaida, ištrinant prieigos raktą",
    "Error while wiping the device with the token" : "Įvyko klaida valant įrenginį panaudojant raktą",
    "App name" : "Programėlės pavadinimas",
    "Create new app password" : "Sukurti naują programėlės slaptažodį",
    "Use the credentials below to configure your app or device." : "Naudokite žemiau esančius prisijungimo duomenis, kad galėtumėte konfigūruoti programėlę ar įrenginį.",
    "For security reasons this password will only be shown once." : "Saugumo sumetimais šis slaptažodis bus parodytas tik vieną kartą.",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Done" : "Atlikta",
    "Show QR code for mobile apps" : "Rodyti mobiliųjų programėlių QR kodą",
    "Copied!" : "Nukopijuota!",
    "Copy" : "Kopijuoti",
    "Could not copy app password. Please copy it manually." : "Nepavyko nukopijuoti programos slaptažodžio. Nukopijuokite jį ranka.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Norint tai paleisti, jums reikia PHP POSIX plėtinio. Išsamesnei informacijai, žiūrėkite {linkstart}PHP dokumentaciją{linkend}.",
    "Profile" : "Profilis",
    "Enable" : "Įjungti",
    "Server-side encryption" : "Šifravimas serverio pusėje",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifravimas serverio pusėje leidžia užšifruoti failus, kurie yra įkelti į serverį. Įjungti tik ik būtinais atvejais.",
    "Enable server-side encryption" : "Įjungti šifravimą serverio pusėje",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Nuo to momento kai šifravimas aktyvuotas, visi failai įkelti į serverį bus užšifruoti ir saugomi serveryje. Vėliau išjungti šifravimą galėsite tik jei šifravimo modulius turi tokią galimybę, ir visos sąlygos (pvz. atstatymo rakto nustatymas) išpildytos.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vien tik šifravimas negarantuoja sistemos saugumo. Išsamesnei informacijai apie tai, kaip veikia šifravimo programėlė ir galimus naudojimo scenarijus, žiūrėkite dokumentaciją.",
    "Be aware that encryption always increases the file size." : "Turėkite omenyje, kad šifravimas visada padidina failų dydį.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Visada yra gerai daryti reguliarias atsargines duomenų kopijas. Esant šifravimui, nepamirškite kartu su savo duomenų atsargine kopija, pasidaryti ir šifravimo raktų atsarginę kopiją.",
    "This is the final warning: Do you really want to enable encryption?" : "Tai yra paskutinis įspėjimas: Ar tikrai norite įjungti šifravimą?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Neįkeltas joks šifravimo modulis, įjunkite šifravimo modulį programėlės meniu.",
    "Select default encryption module:" : "Pasirinkite numatytąjį šifravimo modulį:",
    "Remove group" : "Šalinti grupę",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Jūs ketinate pašalinti grupę {group}. Naudotojai NEBUS ištrinti.",
    "Please confirm the group removal " : "Patvirtinkite grupės pašalinimą",
    "Current password" : "Dabartinis slaptažodis",
    "New password" : "Naujas slaptažodis",
    "Change password" : "Pakeisti slaptažodį",
    "png or jpg, max. 20 MB" : "png arba jpg, daugiausiai 20 MB",
    "Picture provided by original account" : "Paveikslėlis gautas iš pagrindinės paskyros",
    "Cancel" : "Atšaukti",
    "Your biography" : "Jūsų biografija",
    "Your full name" : "Jūsų visas vardas",
    "Remove primary email" : "Šalinti pirminį el. paštą",
    "Delete email" : "Ištrinti el. paštą",
    "This address is not confirmed" : "Šis adresas nėra patvirtintas",
    "Set as primary email" : "Nustatyti kaip pirminį el. paštą",
    "Your email address" : "Jūsų el. pašto adresas",
    "No email address set" : "Nenustatytas joks el. pašto adresas",
    "Language" : "Kalba",
    "Help translate" : "Padėkite išversti",
    "No language set" : "Nenustatyta jokia kalba",
    "Your phone number" : "Jūsų telefono numeris",
    "Edit your Profile visibility" : "Taisyti savo profilio matomumą",
    "Enable Profile" : "Įjungti profilį",
    "Unable to update profile enabled state" : "Nepavyko atnaujinti profilio įjungimo būsenos",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "Nepavyko atnaujinti {displayId} matomumo",
    "Your website" : "Jūsų svetainė",
    "Add" : "Pridėti",
    "You do not have permissions to see the details of this user" : "Jūs neturite leidimų matyti išsamesnę informaciją apie šį naudotoją",
    "Add new password" : "Pridėti naują slaptažodį",
    "Add new email address" : "Pridėti naują el. pašto adresą",
    "Add user to group" : "Pridėti naudotoją į grupę",
    "Set user as admin for" : "Nustatyti vartotoją kaip administratorių ",
    "Select user quota" : "Pasirinkite leidžiamą duomenų kiekį naudotojui",
    "Delete user" : "Ištrinti naudotoją",
    "Wipe all devices" : "Ištrinti duomenis visuose įrenginiuose",
    "Disable user" : "Išjungti naudotoją",
    "Enable user" : "Įjungti naudotoją",
    "Resend welcome email" : "Siųsti dar kartą pasveikinimo el. laišką",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Pametus įrenginį arba pasikeitus darbo santykiams su organizacija, galima nuotoliniu būdu išvalyti „Nextcloud“ duomenis iš visų įrenginių, susietų su {userid}.  Veikia tik su prie interneto prijungtais įrenginiais.",
    "Remote wipe of devices" : "Nuotolinių duomenų įrenginiuose ištrynimas",
    "Wipe {userid}'s devices" : "Ištrinti duomenis naudotojo {userid} įrenginiuose",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Pilnai ištrinta {userid} paskyra, įskaitant visus asmeninius failus, programos duomenis ir pan. ",
    "Account deletion" : "Paskyros ištrynimas",
    "Delete {userid}'s account" : "Ištrinti naudtojo {userid} paskyrą",
    "Welcome mail sent!" : "Pasveikinimo laiškas išsiųstas!",
    "Edit User" : "Taisyti naudotoją",
    "Toggle user actions menu" : "Perjungti vartotojo veiksmų meniu ",
    "{size} used" : "{size} naudojama",
    "New user" : "Naujas naudotojas",
    "Will be autogenerated" : "Bus automatiškai sugeneruotas ",
    "Display name" : "Rodomas vardas",
    "Email" : "El. paštas",
    "Default language" : "Numatytoji kalba",
    "Add a new user" : "Pridėti naują naudotoją",
    "Group admin for" : "Grupės administratorius",
    "Quota" : "Limitas",
    "User backend" : "Naudotojo vidinė pusė",
    "Storage location" : "Saugyklos vieta",
    "Last login" : "Paskutinis prisijungimas",
    "No users in here" : "Čia naudotojų nėra",
    "Default quota" : "Numatytasis leidžiamas duomenų kiekis",
    "Common languages" : "Bendrosios kalbos",
    "Other languages" : "Kitos kalbos",
    "Password change is disabled because the master key is disabled" : "Slaptažodžių keitimas išjungtas, nes yra išjungtas pagrindinis raktas",
    "Passwordless authentication requires a secure connection." : "Tapatybės nustatymas be slaptažodžio reikalauja saugaus ryšio.",
    "Add WebAuthn device" : "Pridėti WebAuthn įrenginį",
    "Please authorize your WebAuthn device." : "Prašome, autorizikuote savo WebAuthn įrenginį.",
    "Name your device" : "Pavadinkite savo įrenginį",
    "Adding your device …" : "Pridedamas jūsų įrenginys …",
    "Server error while trying to add WebAuthn device" : "Serverio klaida, bandant pridėti WbAuthn įrenginį",
    "Server error while trying to complete WebAuthn device registration" : "Serverio klaida, bandant pabaigti WebAuthn įrenginio regsitraciją",
    "Unnamed device" : "Įrenginys be pavadinimo",
    "Passwordless Authentication" : "Tapatybės nustatymas be slaptažodžio",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nustatykite savo paskyrai tapatybės nustatymą be slaptažodžio, pagal FIDO2 standartą.",
    "No devices configured." : "Nėra sukonfiguruotų įrenginių.",
    "The following devices are configured for your account:" : "Jūsų paskyrai sukonfiguruoti šie įrenginiai:",
    "Your browser does not support WebAuthn." : "Jūsų naršyklė nepalaiko WebAuthn.",
    "Your apps" : "Jūsų programėlės",
    "Active apps" : "Aktyvios programėlės",
    "Disabled apps" : "Išjungtos programėlės",
    "Updates" : "Atnaujinimai",
    "App bundles" : "Programėlių rinkiniai",
    "{license}-licensed" : "Licencijuota pagal {license}",
    "Details" : "Išsamiau",
    "Changelog" : "Keitinių žurnalas",
    "by {author}\n{license}" : "pagal {author}\n{license}",
    "Enter group name" : "Įveskite grupės pavadinimą",
    "Add group" : "Pridėti grupę",
    "Active users" : "Aktyvūs naudotojai",
    "Admins" : "Administratoriai",
    "Disabled users" : "Išjungti naudotojai",
    "Default quota:" : "Numatytasis leidžiamas duomenų kiekis:",
    "Select default quota" : "Pasirinkite numatytą leidžiamą duomenų kiekį ",
    "Show Languages" : "Rodyti kalbas",
    "Show last login" : "Rodyti paskutinį prisijungimą",
    "Show user backend" : "Rodyti naudotojo vidinę pusę",
    "Show storage path" : "Rodyti saugyklos kelią",
    "Send email to new user" : "Siųsti naujam naudotojui el. laišką",
    "Not saved" : "Neįrašyta",
    "Sending…" : "Siunčiama…",
    "Email sent" : "El. paštas išsiųstas",
    "Location" : "Vieta",
    "Profile picture" : "Profilio paveikslėlis",
    "About" : "Apie",
    "Full name" : "Vardas, pavardė",
    "Organisation" : "Organizacija",
    "Phone number" : "Telefono numeris",
    "Twitter" : "Twitter",
    "Website" : "Svetainė",
    "Profile visibility" : "Profilio matomumas",
    "Show to everyone" : "Rodyti visiems",
    "Show to logged in users only" : "Rodyti tik prisijungusiems naudotojams",
    "Hide" : "Slėpti",
    "Download and enable" : "Atsisiųsti ir įjungti",
    "Enable untested app" : "Įjungti netestuotą programą",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ši programėlė nėra pažymėta kaip suderinama su jūsų Nextcloud versija. Jei tęsite, vis tiek galėsite įdiegti programėlę. Turėkite omenyje, kad programėlė gali neveikti taip kaip tikimasi.",
    "Never" : "Niekada",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Programėlė įjungta, tačiau turi būti atnaujinta. Po 5 sekundžių būsite peradresuoti į atnaujinimo puslapį.",
    "Administrator documentation" : "Administratoriaus dokumentacija",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forumas",
    "Login" : "Prisijungti",
    "Plain" : "Paprastas",
    "NT LAN Manager" : "NT LAN tvarkytuvė",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Atverti dokumentaciją",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Svarbu nustatyti šį serverį, kad galėtumėte siųsti el. laiškus, kaip, pavyzdžiui, slaptažodžio atstatymą ar pranešimus.",
    "Send mode" : "Siuntimo veiksena",
    "Encryption" : "Šifravimas",
    "Sendmail mode" : "El. pašto siuntimo veiksena",
    "From address" : "Siuntėjo adresas",
    "Authentication method" : "Tapatybės nustatymo metodas",
    "Authentication required" : "Reikalingas tapatybės nustatymas",
    "Server address" : "Serverio adresas",
    "Port" : "Prievadas",
    "Credentials" : "Prisijungimo duomenys",
    "SMTP Username" : "SMTP naudotojo vardas",
    "SMTP Password" : "SMTP slaptažodis",
    "Save" : "Įrašyti",
    "Send email" : "Siųsti el. paštą",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Siekiant jūsų egzemplioriaus saugumo ir našumo, yra svarbu, kad viskas būtų teisingai sukonfigūruota. Norėdami jums padėti, atliekame tam tikrus automatinius patikrinimus. Išsamesnei informacijai, žiūrėkite susietą dokumentaciją.",
    "All checks passed." : "Visi patikros rezultatai teigiami.",
    "There are some errors regarding your setup." : "Yra klaidų, susijusių su jūsų sąranką.",
    "There are some warnings regarding your setup." : "Yra įspėjimų, susijusių su jūsų sąranka.",
    "Checking for system and security issues." : "Tikrinamos sistemos ir saugumo problemos.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Dar kartą peržiūrėkite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">įdiegimo vadovą ↗</a> bei patikrinkite ar <a href=\"%2$s\">žurnale</a> nėra jokių klaidų ar įspėjimų.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Patikrinkite savo Nextcloud saugumą naudodamiesi <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">mūsų saugumo nuskaitymu ↗</a>.",
    "Version" : "Versija",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Būdami administratoriumi, galite reguliuoti bendrinimo elgseną. Išsamesnei informacijai, žiūrėkite dokumentaciją.",
    "Allow apps to use the Share API" : "Leisti programėlėms naudoti bendrinimo API",
    "Set default expiration date for shares" : "Nustatyti viešiniams numatytąją galiojimo pabaigos datą",
    "Enforce expiration date" : "Priverstinė galiojimo pabaigos data",
    "Allow public uploads" : "Leisti viešus įkėlimus",
    "Always ask for a password" : "Visada prašyti slaptažodžio",
    "Enforce password protection" : "Priverstinė apsauga slaptažodžiu",
    "Set default expiration date" : "Nustatyti numatytąją galiojimo pabaigos datą",
    "Allow resharing" : "Leisti bendrinti iš naujo",
    "Allow sharing with groups" : "Leisti bendrinti su grupėmis",
    "Restrict users to only share with users in their groups" : "Apriboti naudotojus ir leisti jiems bendrinti tik su naudotojais savo grupėse",
    "Exclude groups from sharing" : "Išskirti grupes iš bendrinimo",
    "These groups will still be able to receive shares, but not to initiate them." : "Šios grupės vis tiek galės gauti viešinius, tačiau negalės jų inicijuoti.",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Rodyti atsakomybės ribojimo tekstą įkėlimo per viešąją nuorodą puslapyje (rodomas tik tada, kai failų sąrašas yra paslėptas)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Šis tekstas bus rodomas viešų nuorodų įkėlimo puslapyje, kai failų sąrašas bus paslėptas.",
    "Default share permissions" : "Numatytieji viešinių leidimai",
    "Reasons to use Nextcloud in your organization" : "Priežastys, kodėl turėtumėte naudoti Nextcloud savo organizacijoje",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Sukurta {communityopen}Nextcloud bendruomenės{linkclose}, {githubopen}pirminis kodas{linkclose} yra licencijuotas pagal {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Spauskite „Patinka“ mūsų „Facebook“ puslapyje",
    "Follow us on Twitter" : "Sekite mus Twitter",
    "Follow us on Mastodon" : "Sekite mus Mastodon",
    "Check out our blog" : "Peržvelkite mūsų tinklaraštį",
    "Subscribe to our newsletter" : "Prenumeruokite mūsų naujienlaiškį",
    "You are a member of the following groups:" : "Jūs esate šių grupių narys:",
    "You are using <strong>%s</strong>" : "Jūs naudojate <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Jūs naudojate <strong>%1$s</strong> iš <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Locale" : "Lokalė",
    "Use a second factor besides your password to increase security for your account." : "Be savo slaptažodžio naudokite ir antrąjį faktorių, kad padidintumėte savo paskyros saugumą.",
    "Migration in progress. Please wait until the migration is finished" : "Vyksta perkėlimas. Palaukite, kol perkėlimas bus užbaigtas",
    "Migration started …" : "Perkėlimas pradėtas …",
    "Select a profile picture" : "Pasirinkite profilio paveikslėlį",
    "Couldn't remove app." : "Nepavyko pašalinti programėlės.",
    "Couldn't update app." : "Nepavyko atnaujinti programėlės.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Vidinė pusė nepalaiko slaptažodžio keitimo, tačiau naudotojo šifravimo raktas buvo atnaujintas.",
    "You need to set your user email before being able to send test emails." : "Prieš galėdami siųsti bandomuosius el. laiškus, turite nusistatyti savo naudotojo el. paštą.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Panaikinus šį prieigos raktą, jums gali būti neleista ištrinti šio įrenginio duomenų, jeigu jis dar nepradėjo duomenų ištrynimo.",
    "All languages" : "Visos kalbos",
    "Everyone" : "Visi",
    "An error occured during the request. Unable to proceed." : "Užklausos metu, įvyko klaida. Nepavyksta tęsti.",
    "Test email settings" : "Išbandyti el. pašto nustatymus",
    "Please read carefully before activating server-side encryption: " : "Prieš aktyvuodami šifravimą serverio pusėje, įdėmiai perskaitykite:",
    "Enable encryption" : "Įjungti šifravimą",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį. Prašome įjungti „Numatytąjį šifravimo modulį“ ir įvykdyti „occ encryption:migrate“",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Jūs turite perkelti savo šifravimo raktus iš senojo šifravimo (ownCloud <= 8.0) į naująjį.",
    "Start migration" : "Pradėti perkėlimą",
    "Last job execution ran %s. Something seems wrong." : "Paskutinės užduoties vykdymas vyko %s. Atrodo, kad kažkas nutiko.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Keletas darbų nebuvo pradėti vykdyti nuo %s.  Prašome, apsvarstykite galimybę padidinti vykdymo dažnį.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Keletas darbų nebevykdomi nuo %s. Apsvarstykite darbų perkėlimą į cron.",
    "Last job ran %s." : "Paskutinė užduotis buvo vykdyta %s.",
    "Background job didn’t run yet!" : "Foninės užduotys kol kas nebuvo vykdomos!",
    "Pick background job setting" : "Parinkite foninių darbų nustatymus",
    "Recommended" : "Rekomenduojama",
    "The cron.php needs to be executed by the system user \"%s\"." : "Cron.php turi įvykdyti sistemos naudotojas „%s“.",
    "days" : "dienos",
    "Upload new" : "Įkelti naują",
    "Select from Files" : "Pasirinkti iš failų",
    "Remove image" : "Šalinti paveikslą",
    "Choose as profile picture" : "Pasirinkti kaip profilio paveikslėlį",
    "No display name set" : "Rodomas vardas nenurodytas",
    "Address" : "Adresas",
    "Your postal address" : "Jūsų adresas",
    "It can take up to 24 hours before the account is displayed as verified." : "Gali užtrukti iki 24 valandų, kol paskyra bus rodoma kaip patikrinta. ",
    "Link https://…" : "Nuoroda https://…",
    "Twitter handle @…" : "Twitter rankenėlė @…",
    "Unable to update biography" : "Nepavyko atnaujinti biografijos",
    "Unable to update full name" : "Nepavyko atnaujinti viso vardo",
    "No full name set" : "Nenustatyta jokio viso vardo",
    "Avatar" : "Avataras"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
